read_csv: reads a csv from a url with a csv

View source: R/utils.R

read_csvR Documentation

reads a csv from a url with a csv

Description

reads a csv from a url with a csv

Usage

read_csv(file_url)

Arguments

file_url

A URL to a CSV file.

Value

A data frame with the first few rows of the CSV file.


usportsR documentation built on March 16, 2026, 5:08 p.m.