| read_csv | R Documentation |
reads a csv from a url with a csv
read_csv(file_url)
file_url |
A URL to a CSV file. |
A data frame with the first few rows of the CSV file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.